/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2003 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.community;

import java.security.Principal;
import java.security.acl.AclNotFoundException;
import java.util.*;
import com.silverwrist.dynamo.except.*;
import com.silverwrist.dynamo.iface.*;
import com.silverwrist.venice.CommunityVisibility;
import com.silverwrist.venice.iface.*;

abstract class CommunityProxy implements VeniceCommunity, DynamicWrapper
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  protected int m_id;

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  CommunityProxy(int cid)
  {
    m_id = cid;

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Abstract operations
   *--------------------------------------------------------------------------------
   */

  protected abstract VeniceCommunity getRealCommunity();

  /*--------------------------------------------------------------------------------
   * Overrides from class Object
   *--------------------------------------------------------------------------------
   */

  public boolean equals(Object o)
  {
    if (o==null)
      return false;
    if (o instanceof VeniceCommunity)
      return (((VeniceCommunity)o).getCID()==m_id);
    return false;

  } // end equals

  public int hashCode()
  {
    return m_id;

  } // end hashCode

  public String toString()
  {
    return "Community #" + m_id;

  } // end toString

  /*--------------------------------------------------------------------------------
   * Implementations from interface NamedObject
   *--------------------------------------------------------------------------------
   */

  /**
   * Returns the name of this community.
   *
   * @return The name of this community.
   */
  public String getName()
  {
    return getRealCommunity().getName();

  } // end getName

  /*--------------------------------------------------------------------------------
   * Implementations from interface ObjectProvider
   *--------------------------------------------------------------------------------
   */

  /**
   * Retrieves an object from this <CODE>ObjectProvider</CODE>.
   *
   * @param namespace The namespace to interpret the name relative to.
   * @param name The name of the object to be retrieved.
   * @return The object reference specified.
   */
  public Object getObject(String namespace, String name)
  {
    return getRealCommunity().getObject(namespace,name);

  } // end getObject

  /*--------------------------------------------------------------------------------
   * Implementations from interface SecureObjectStore
   *--------------------------------------------------------------------------------
   */

  public Object setObject(DynamoUser caller, String namespace, String name, Object value)
      throws DatabaseException, DynamoSecurityException
  {
    return getRealCommunity().setObject(caller,namespace,name,value);

  } // end setObject

  public Object removeObject(DynamoUser caller, String namespace, String name)
      throws DatabaseException, DynamoSecurityException
  {
    return getRealCommunity().removeObject(caller,namespace,name);

  } // end removeObject

  public Collection getNamespaces() throws DatabaseException
  {
    return getRealCommunity().getNamespaces();

  } // end getNamespaces

  public Collection getNamesForNamespace(String namespace) throws DatabaseException
  {
    return getRealCommunity().getNamesForNamespace(namespace);

  } // end getNamesForNamespace

  /*--------------------------------------------------------------------------------
   * Implementations from interface VeniceCommunity
   *--------------------------------------------------------------------------------
   */

  public int getCID()
  {
    return m_id;

  } // end getCID

  public int getMemberGID()
  {
    return getRealCommunity().getMemberGID();

  } // end getMemberGID

  public DynamoGroup getMemberGroup() throws DatabaseException
  {
    return getRealCommunity().getMemberGroup();

  } // end getMemberGroup

  public int getHostGID()
  {
    return getRealCommunity().getHostGID();

  } // end getHostGID

  public DynamoGroup getHostGroup() throws DatabaseException
  {
    return getRealCommunity().getHostGroup();

  } // end getHostGroup

  public int getHostUID()
  {
    return getRealCommunity().getHostUID();

  } // end getHostUID

  public DynamoUser getHostUser() throws DatabaseException
  {
    return getRealCommunity().getHostUser();

  } // end getHostUser

  public DynamoAcl getAcl() throws DatabaseException, AclNotFoundException
  {
    return getRealCommunity().getAcl();

  } // end getAcl

  public int getCategoryID()
  {
    return getRealCommunity().getCategoryID();

  } // end getCategoryID

  public VeniceCategory getCategory() throws DatabaseException
  {
    return getRealCommunity().getCategory();

  } // end getCategory

  public synchronized void setCategoryID(DynamoUser caller, int catid)
      throws DatabaseException, DynamoSecurityException
  {
    getRealCommunity().setCategoryID(caller,catid);

  } // end setCategoryID

  public void setCategory(DynamoUser caller, VeniceCategory cat) throws DatabaseException, DynamoSecurityException
  {
    this.setCategoryID(caller,cat.getCategoryID());

  } // end setCategory

  public CommunityVisibility getVisibility()
  {
    return getRealCommunity().getVisibility();

  } // end getVisibility

  public synchronized void setVisibility(DynamoUser caller, CommunityVisibility vis)
      throws DatabaseException, DynamoSecurityException
  {
    getRealCommunity().setVisibility(caller,vis);

  } // end setVisibility

  public synchronized void setName(DynamoUser caller, String name) throws DatabaseException, DynamoSecurityException
  {
    getRealCommunity().setName(caller,name);

  } // end setName

  public String getAlias()
  {
    return getRealCommunity().getAlias();

  } // end getAlias

  public synchronized void setAlias(DynamoUser caller, String alias) throws DatabaseException, DynamoSecurityException
  {
    getRealCommunity().setAlias(caller,alias);

  } // end setAlias

  public java.util.Date getCreationDate()
  {
    return getRealCommunity().getCreationDate();

  } // end getCreationDate

  public java.util.Date getLastAccessDate()
  {
    return getRealCommunity().getLastAccessDate();

  } // end getLastAccessDate

  public synchronized void setLastAccessDate(DynamoUser caller, java.util.Date date)
      throws DatabaseException, DynamoSecurityException
  {
    getRealCommunity().setLastAccessDate(caller,date);

  } // end setLastAccessedDate

  public java.util.Date getLastUpdateDate()
  {
    return getRealCommunity().getLastUpdateDate();

  } // end getLastUpdateDate

  public synchronized void setLastUpdateDate(DynamoUser caller, java.util.Date date)
      throws DatabaseException, DynamoSecurityException
  {
    getRealCommunity().setLastUpdateDate(caller,date);

  } // end setLastUpdateDate

  public void grantAccess(DynamoUser caller, Principal subject, String auth_namespace, String auth_name,
			  String source_info, String auth_info, boolean single_use)
      throws AuthenticationException, DatabaseException, DynamoSecurityException
  {
    getRealCommunity().grantAccess(caller,subject,auth_namespace,auth_name,source_info,auth_info,single_use);

  } // end grantAccess

  public void revokeAccess(DynamoUser caller, Principal subject) throws DatabaseException, DynamoSecurityException
  {
    getRealCommunity().revokeAccess(caller,subject);

  } // end revokeAccess

  /*--------------------------------------------------------------------------------
   * Implementations from interface DynamicWrapper
   *--------------------------------------------------------------------------------
   */

  public Object unwrap()
  {
    return getRealCommunity();

  } // end unwrap

} // end class CommunityProxy
